"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useGoogleReCaptchaV3 = exports.default = void 0;

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var _react = require("react");

var _htmlDom = require("../../utils/html-dom");

// https://developers.google.com/recaptcha/docs/v3
var ERROR_SCRIPT_NOT_AVAILABLE = 'Google recaptcha is not available';
var ERROR_NOT_A_WEB_BROWSER = 'Running outside a web browser';
var GOOGLE_RECAPTCHA_V3_SCRIPT = 'https://www.google.com/recaptcha/api.js';
var SCRIPT_ID = 'google-recaptcha-v3';
var GOOGLE_RECAPTCHA_BADGE_CLASSNAME = '.grecaptcha-badge';

var useGoogleReCaptchaV3 = function useGoogleReCaptchaV3(_ref) {
  var siteKey = _ref.siteKey,
      language = _ref.language,
      _ref$loadOnStart = _ref.loadOnStart,
      loadOnStart = _ref$loadOnStart === void 0 ? false : _ref$loadOnStart,
      action = _ref.action;

  var _useState = (0, _react.useState)(),
      _useState2 = (0, _slicedToArray2.default)(_useState, 2),
      responseToken = _useState2[0],
      setResponseToken = _useState2[1];

  var executeReCaptcha = (0, _react.useCallback)( /*#__PURE__*/function () {
    var _ref2 = (0, _asyncToGenerator2.default)( /*#__PURE__*/_regenerator.default.mark(function _callee(action) {
      var window, grecaptcha;
      return _regenerator.default.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              window = (0, _htmlDom.getProjectWindow)();

              if (window) {
                _context.next = 3;
                break;
              }

              throw new Error(ERROR_NOT_A_WEB_BROWSER);

            case 3:
              grecaptcha = window.grecaptcha;

              if (grecaptcha) {
                _context.next = 6;
                break;
              }

              throw new Error(ERROR_SCRIPT_NOT_AVAILABLE);

            case 6:
              return _context.abrupt("return", new Promise(function (resolve) {
                grecaptcha.ready(function () {
                  grecaptcha.execute(siteKey, {
                    action: action
                  }).then(function (token) {
                    return resolve(token);
                  });
                });
              }));

            case 7:
            case "end":
              return _context.stop();
          }
        }
      }, _callee);
    }));

    return function (_x) {
      return _ref2.apply(this, arguments);
    };
  }(), [siteKey]);

  var removeGReCaptchaDivElement = function removeGReCaptchaDivElement() {
    var window = (0, _htmlDom.getProjectWindow)();
    if (!window) return;
    var element = document.querySelector(GOOGLE_RECAPTCHA_BADGE_CLASSNAME);

    if (element && element.parentElement) {
      element.parentElement.remove();
    }
  };

  var onLoadInjectedScript = /*#__PURE__*/function () {
    var _ref3 = (0, _asyncToGenerator2.default)( /*#__PURE__*/_regenerator.default.mark(function _callee2() {
      var token;
      return _regenerator.default.wrap(function _callee2$(_context2) {
        while (1) {
          switch (_context2.prev = _context2.next) {
            case 0:
              if (loadOnStart) {
                _context2.next = 2;
                break;
              }

              return _context2.abrupt("return");

            case 2:
              _context2.prev = 2;
              _context2.next = 5;
              return executeReCaptcha(action);

            case 5:
              token = _context2.sent;
              setResponseToken(token);
              _context2.next = 12;
              break;

            case 9:
              _context2.prev = 9;
              _context2.t0 = _context2["catch"](2);
              console.warn(_context2.t0);

            case 12:
            case "end":
              return _context2.stop();
          }
        }
      }, _callee2, null, [[2, 9]]);
    }));

    return function onLoadInjectedScript() {
      return _ref3.apply(this, arguments);
    };
  }();

  (0, _react.useEffect)(function () {
    if (!siteKey) return;
    var window = (0, _htmlDom.getProjectWindow)();

    if (window) {
      var scriptTag = window.document.getElementById(SCRIPT_ID);

      if (!scriptTag) {
        (0, _htmlDom.injectScript)(SCRIPT_ID, "".concat(GOOGLE_RECAPTCHA_V3_SCRIPT, "?render=").concat(siteKey).concat(language ? "&hl=".concat(language) : ''), onLoadInjectedScript);
      }
    }

    return function () {
      (0, _htmlDom.removeScript)(SCRIPT_ID);
      removeGReCaptchaDivElement();
    };
  }, [siteKey, language]);
  return {
    executeReCaptcha: executeReCaptcha,
    reCaptchaResponseToken: responseToken
  };
};

exports.useGoogleReCaptchaV3 = useGoogleReCaptchaV3;
var _default = useGoogleReCaptchaV3;
exports.default = _default;